﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Windows;
using System.IO;
using System.Net;
using System.Diagnostics;

namespace Interlight
{
    public partial class settings : Form
    {
        delegate void SetTextCallback(string text);

        //VERSION
        public String version = "3.0.0.0";

        public int tabNumber = 0;
        public String currentURL = "";

        public settings()
        {
            InitializeComponent();
        }

        private void settings_Load(object sender, EventArgs e)
        {
            //Hide 'Add favorite' items
            fLbl1.Visible = false;
            fLbl2.Visible = false;
            fLbl3.Visible = false;
            fLbl4.Visible = false;

            //Load History
            try
            {
                for (int i=Properties.Settings.Default.history.Count; i > 0; i--)
                {
                    historyItems.Items.Add(Properties.Settings.Default.history[i-1]);
                }
            }
            catch
            {
            }

            //Load Favorite
            try
            {
                for (int i = 0; i < Properties.Settings.Default.favorites.Count; i++)
                {
                    favoriteItems.Items.Add(Properties.Settings.Default.favorites[i]);
                }
            }
            catch
            {
            }

            //Load Download History
            try
            {
                for (int i = Properties.Settings.Default.dlHistory.Count; i > 0; i--)
                {
                    downloadItems.Items.Add(Properties.Settings.Default.dlHistory[i - 1]);
                }
            }
            catch
            {
            }

            //Load the search engine preference
            String search = Properties.Settings.Default.searchEngine;
            switch (search)
            {
                case "bing":
                    bingCheck.Checked = true;
                    break;
                case "google":
                    googleCheck.Checked = true;
                    break;
                case "yahoo":
                    yahooCheck.Checked = true;
                    break;
                case "wikipedia":
                    wikipediaCheck.Checked = true;
                    break;
                case "amazon":
                    amazonCheck.Checked = true;
                    break;
                case "baidu":
                    baiduCheck.Checked = true;
                    break;
                case "naver":
                    naverCheck.Checked = true;
                    break;
            }

            //Load Settings
            homePage.Text = Properties.Settings.Default.homeUrl;

            if (addNew == true)
            {
                addNew = false;
                fLbl1.Visible = true;
                fLbl2.Visible = true;
                fLbl3.Visible = true;
                fLbl4.Visible = true;
                fCancelBtn.Visible = true;
                fLbl2.Text = currentURL;
            }

            //Select the tab
            tab.SelectTab(tabNumber);

            System.Threading.Thread thr = new System.Threading.Thread(cfuMtd);
            thr.Start();

            System.Threading.Thread thr2 = new System.Threading.Thread(cfuInfoMtd);
            thr2.Start();
        }

        private void cfuInfoMtd()
        {
            //Retrieve the update info
            try
            {
                WebRequest request = WebRequest.Create("http://www.mobilemp.net/Interlight/changelog.html");
                using (WebResponse response = request.GetResponse())
                {
                    using (StreamReader reader = new StreamReader(response.GetResponseStream()))
                    {
                        String data = reader.ReadToEnd();
                        SetInfo(data);

                        reader.Close();
                        response.Close();
                    }
                }
            }
            catch
            {
                SetInfo("Couldn't connect to MobileMP's server. Please try again later.");
            }
        }

        private void SetInfo(string text)
        {
            // InvokeRequired required compares the thread ID of the 
            // calling thread to the thread ID of the creating thread. 
            // If these threads are different, it returns true. 
            if (this.cfuInfo.InvokeRequired)
            {
                SetTextCallback d = new SetTextCallback(SetInfo);
                this.Invoke(d, new object[] { text });
            }
            else
            {
                this.cfuInfo.Text = text;
            }
        }

        private void cfuMtd()
        {
            //Check for update available
            try
            {
                System.Net.WebRequest cfu = System.Net.WebRequest.Create("http://www.mobilemp.net/Interlight/version.html");
                using (System.Net.WebResponse response = cfu.GetResponse())
                {
                    using (System.IO.StreamReader reader = new System.IO.StreamReader(response.GetResponseStream()))
                    {
                        String data = reader.ReadToEnd();
                        response.Close();
                        reader.Close();

                        if (data == version)
                        {
                            SetText("Interlight is up to date! You're using version " + version + ".");
                            setBtnText("Reinstall");
                        }
                        else
                        {
                            SetText("Interlight's out of date! Update to " + data + ", you're using " + version + ".");
                            setBtnText("Update");
                        }
                    }
                }
            }
            catch
            {
                SetText("Couldn't connect to MobileMP's server. Please try again later.");
            }
        }

        private void SetText(string text)
        {
            // InvokeRequired required compares the thread ID of the 
            // calling thread to the thread ID of the creating thread. 
            // If these threads are different, it returns true. 
            if (this.cfuLabel.InvokeRequired)
            {
                SetTextCallback d = new SetTextCallback(SetText);
                this.Invoke(d, new object[] { text });
            }
            else
            {
                this.cfuLabel.Text = text;
            }
        }

        private void setBtnText(string text)
        {
            // InvokeRequired required compares the thread ID of the 
            // calling thread to the thread ID of the creating thread. 
            // If these threads are different, it returns true. 
            if (this.button8.InvokeRequired)
            {
                SetTextCallback d = new SetTextCallback(setBtnText);
                this.Invoke(d, new object[] { text });
            }
            else
            {
                this.button8.Text = text;
            }
        }

        bool addNew = false;

        public void selectTab(int i)
        {
            if (i != 99)
            {
                tabNumber = i;
            }
            else
            {
                tabNumber = 3;
                addNew = true;
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.history.RemoveAt(historyItems.SelectedIndex);
                historyItems.Items.RemoveAt(historyItems.SelectedIndex);
                Properties.Settings.Default.Save();
            }
            catch
            {
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = historyItems.Items[historyItems.SelectedIndex].ToString();
                this.Close();
            }
            catch
            {
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void button3_Click(object sender, EventArgs e)
        {
            saveNow();
            this.Close();
        }

        private void button5_Click(object sender, EventArgs e)
        {
            saveNow();
        }

        /// <summary>
        /// Save the settings that are currently displayed.
        /// </summary>
        private void saveNow()
        {
            //Save the homepage
            if (Uri.IsWellFormedUriString(homePage.Text, UriKind.RelativeOrAbsolute))
            {
                Properties.Settings.Default.homeUrl = homePage.Text;
            }
            else
            {
                MessageBox.Show("That doesn't seem like a valid URL to me!", "Interlight");
                return;
            }

            //Save search engine preference
            if (bingCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "bing";
            }
            else if (googleCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "google";
            }
            else if (yahooCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "yahoo";
            }
            else if (wikipediaCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "wikipedia";
            }
            else if (amazonCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "amazon";
            }
            else if (baiduCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "baidu";
            }
            else if (naverCheck.Checked == true)
            {
                Properties.Settings.Default.searchEngine = "naver";
            }

            //Finally, finish the save of settings
            Properties.Settings.Default.Save();
        }

        private void button6_Click(object sender, EventArgs e)
        {
            int itemCount = Properties.Settings.Default.history.Count;

            Properties.Settings.Default.history.Clear();
            historyItems.Items.Clear();

            Properties.Settings.Default.Save();
        }

        public void currentPage(String url)
        {
            currentURL = url;
        }

        private void button7_Click(object sender, EventArgs e)
        {
            homePage.Text = currentURL;
        }

        private void historyItems_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = historyItems.Items[historyItems.SelectedIndex].ToString();
                this.Close();
            }
            catch
            {
            }
        }

        private void button8_Click(object sender, EventArgs e)
        {
            try
            {
                ProcessStartInfo processInfo = new ProcessStartInfo();
                processInfo.Verb = "runas";
                processInfo.FileName = "Interlight Updater.exe";
                Process.Start(processInfo);
                Environment.Exit(0);
            }
            catch
            {

            }
        }

        private void button11_Click(object sender, EventArgs e)
        {
            fLbl1.Visible = true;
            fLbl2.Visible = true;
            fLbl3.Visible = true;
            fLbl4.Visible = true;
            fCancelBtn.Visible = true;
        }

        private void fLbl3_Click(object sender, EventArgs e)
        {
            fLbl2.Text = currentURL;
        }

        private void fLbl4_Click(object sender, EventArgs e)
        {
            fLbl1.Visible = false;
            fLbl2.Visible = false;
            fLbl3.Visible = false;
            fLbl4.Visible = false;
            fCancelBtn.Visible = false;

            try
            {
                Properties.Settings.Default.favorites.Add(fLbl2.Text);
                favoriteItems.Items.Add(fLbl2.Text);
                Properties.Settings.Default.Save();
                fLbl2.Text = "";
            }
            catch
            {
            }
        }

        private void button9_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.favorites.RemoveAt(favoriteItems.SelectedIndex);
                favoriteItems.Items.RemoveAt(favoriteItems.SelectedIndex);
                Properties.Settings.Default.Save();
            }
            catch
            {
            }
        }

        private void button10_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = favoriteItems.Items[favoriteItems.SelectedIndex].ToString();
                this.Close();
            }
            catch
            {
            }
        }

        private void favoriteItems_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = favoriteItems.Items[favoriteItems.SelectedIndex].ToString();
                this.Close();
            }
            catch
            {
            }
        }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            if (textBox1.Text == "")
            {
                button1.Enabled = true;
                historyItems.Items.Clear();
                
                try
                {
                    for (int i = Properties.Settings.Default.history.Count; i > 0; i--)
                    {
                        historyItems.Items.Add(Properties.Settings.Default.history[i - 1]);
                    }
                }
                catch
                {
                }
            }

            else
            {
                button1.Enabled = false;
                historyItems.Items.Clear();

                try
                {
                    for (int i = Properties.Settings.Default.history.Count; i > 0; i--)
                    {
                        if (Properties.Settings.Default.history[i - 1].Contains(textBox1.Text))
                        {
                            historyItems.Items.Add(Properties.Settings.Default.history[i - 1]);
                        }
                    }
                }
                catch
                {
                }
            }
        }

        private void button12_Click(object sender, EventArgs e)
        {
            textViewer viewer = new textViewer();
            viewer.Show();
            viewer.loadText("Privacy Policy", 
                "Hello there! We are going to explain to you what we do with your information, including your usage habits and your settings." + Environment.NewLine + Environment.NewLine +
                "Short and only answer: We don't do anything with your information, including any of those above or more. The only reason that this program touches MobileMP's server is to check for updates to make this product even better than it was before." + Environment.NewLine + Environment.NewLine +
                "Wondering about where every single byte of data about you goes? It stays on your computer! History, favorites, navigating to other websites, you name it! All that data is on only one location, your own PC, and it will stay there." + Environment.NewLine + Environment.NewLine +
                "Thanks for taking the time to read our Privacy Policy. Have any questions? contact@mobilemp.net"
                );
        }

        private void button13_Click(object sender, EventArgs e)
        {
            textViewer viewer = new textViewer();
            viewer.Show();
            viewer.loadText("Copyright", "document");
        }

        private void cfuInfo_LinkClicked(object sender, LinkClickedEventArgs e)
        {
            string[] args = { e.LinkText };
            Form1 frm = new Form1(args);
            frm.Show();
        }

        private void button14_Click(object sender, EventArgs e)
        {
            try
            {
                ProcessStartInfo processInfo = new ProcessStartInfo();
                processInfo.Verb = "runas";
                processInfo.FileName = "Delete Cookies.exe";
                Process.Start(processInfo);
                Environment.Exit(0);
            }
            catch
            {

            }
        }

        private void button15_Click(object sender, EventArgs e)
        {
            try
            {
                ProcessStartInfo processInfo = new ProcessStartInfo();
                processInfo.Verb = "runas";
                processInfo.FileName = "ClearCache.exe";
                Process.Start(processInfo);
                Environment.Exit(0);
            }
            catch
            {

            }
        }

        private void button16_Click(object sender, EventArgs e)
        {
            try
            {
                ProcessStartInfo processInfo = new ProcessStartInfo();
                processInfo.Verb = "runas";
                processInfo.FileName = "Delete Local Storage.exe";
                Process.Start(processInfo);
                Environment.Exit(0);
            }
            catch
            {

            }
        }

        private void goToThisPageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button2.PerformClick();
        }

        private void deleteThisSiteToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button1.PerformClick();
        }

        private void deleteAllHistoryToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button6.PerformClick();
        }

        private void historyItems_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Right)
            {
                historyItems.SelectedIndex = historyItems.IndexFromPoint(e.X, e.Y);
            }
        }

        private void favoriteItems_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Right)
            {
                favoriteItems.SelectedIndex = favoriteItems.IndexFromPoint(e.X, e.Y);
            }
        }

        private void goToThisSiteToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button10.PerformClick();
        }

        private void deleteThisSiteToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            button9.PerformClick();
        }

        private void addAFavoriteToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button11.PerformClick();
        }

        private void fCancelBtn_Click(object sender, EventArgs e)
        {
            fLbl1.Visible = false;
            fLbl2.Visible = false;
            fLbl3.Visible = false;
            fLbl4.Visible = false;
            fCancelBtn.Visible = false;
            fLbl2.Text = "";
        }

        private void linkLabel2_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = "http://get2.adobe.com/flashplayer/otherversions/";
                MessageBox.Show("IMPORTANT: You must change the browser to Firefox. It will not work if you don't.", "NOTICE! Please read!");
                this.Close();
            }
            catch
            {
                Clipboard.SetText("http://get2.adobe.com/flashplayer/otherversions/");
                MessageBox.Show("Couldn't navigate you to the Adobe Flash webpage. Try going there manually, the URL has been copied to your clipboard.", "Error");
            }
        }

        private void linkLabel3_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = "http://interlight.codeplex.com/documentation";
                this.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show("Couldn't navigate you to Interlight Online Help. Sorry about that." + Environment.NewLine + ex, "Error");
            }
        }

        private void button17_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.navigateTo = downloadItems.Items[downloadItems.SelectedIndex].ToString();
                this.Close();
            }
            catch
            {
            }
        }

        private void downloadItems_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            button17.PerformClick();
        }

        private void downloadItems_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Right)
            {
                downloadItems.SelectedIndex = downloadItems.IndexFromPoint(e.X, e.Y);
            }
        }

        private void button18_Click(object sender, EventArgs e)
        {
            try
            {
                Properties.Settings.Default.dlHistory.RemoveAt(downloadItems.SelectedIndex);
                downloadItems.Items.RemoveAt(downloadItems.SelectedIndex);
                Properties.Settings.Default.Save();
            }
            catch
            {
            }
        }

        private void downloadSelectedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button17.PerformClick();
        }

        private void deleteFromListToolStripMenuItem_Click(object sender, EventArgs e)
        {
            button18.PerformClick();
        }
    }
}
